@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -54,6 +56,13 @@ Input parameter for silent mode: empty.
         self.LivenessType = params.get("LivenessType")
         self.ValidateData = params.get("ValidateData")
         self.Optional = params.get("Optional")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class LivenessCompareResponse(AbstractModel):
@@ -90,4 +99,11 @@ class LivenessCompareResponse(AbstractModel):
         self.Result = params.get("Result")
         self.Description = params.get("Description")
         self.BestFrameList = params.get("BestFrameList")
-        self.RequestId = params.get("RequestId")
\ No newline at end of file
+        self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
